# coding: utf-8

"""
    Xray REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictStr
from typing_extensions import Annotated

from openapi_client.api_client import ApiClient, RequestSerialized
from openapi_client.api_response import ApiResponse
from openapi_client.rest import RESTResponseType


class TestPlanTestExecutionsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def call_10_api_testplan_test_plan_key_testexecution_get(
        self,
        test_plan_key: Annotated[StrictStr, Field(description="key of the test plan.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """call_10_api_testplan_test_plan_key_testexecution_get

        Returns a JSON object with a list of the test executions associated with the test plan.

        :param test_plan_key: key of the test plan. (required)
        :type test_plan_key: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._call_10_api_testplan_test_plan_key_testexecution_get_serialize(
            test_plan_key=test_plan_key,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "Error",
            '401': "Error",
            '500': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def call_10_api_testplan_test_plan_key_testexecution_get_with_http_info(
        self,
        test_plan_key: Annotated[StrictStr, Field(description="key of the test plan.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """call_10_api_testplan_test_plan_key_testexecution_get

        Returns a JSON object with a list of the test executions associated with the test plan.

        :param test_plan_key: key of the test plan. (required)
        :type test_plan_key: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._call_10_api_testplan_test_plan_key_testexecution_get_serialize(
            test_plan_key=test_plan_key,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "Error",
            '401': "Error",
            '500': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def call_10_api_testplan_test_plan_key_testexecution_get_without_preload_content(
        self,
        test_plan_key: Annotated[StrictStr, Field(description="key of the test plan.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """call_10_api_testplan_test_plan_key_testexecution_get

        Returns a JSON object with a list of the test executions associated with the test plan.

        :param test_plan_key: key of the test plan. (required)
        :type test_plan_key: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._call_10_api_testplan_test_plan_key_testexecution_get_serialize(
            test_plan_key=test_plan_key,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "Error",
            '401': "Error",
            '500': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _call_10_api_testplan_test_plan_key_testexecution_get_serialize(
        self,
        test_plan_key,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if test_plan_key is not None:
            _path_params['testPlanKey'] = test_plan_key
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth', 
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/1.0/api/testplan/{testPlanKey}/testexecution',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def call_10_api_testplan_test_plan_key_testexecution_post(
        self,
        test_plan_key: Annotated[StrictStr, Field(description="key of the test plan.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """call_10_api_testplan_test_plan_key_testexecution_post

        Associate test executions with the test plan. Return error messages, if there are any. It's possible to specify if the tests in the test execution should be added to the test plan using the \"addTestsToPlan\" property in the JSON file. If this setting is empty in the JSON file, the config in the Xray miscellaneous will be used.

        :param test_plan_key: key of the test plan. (required)
        :type test_plan_key: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._call_10_api_testplan_test_plan_key_testexecution_post_serialize(
            test_plan_key=test_plan_key,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "Error",
            '401': "Error",
            '500': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def call_10_api_testplan_test_plan_key_testexecution_post_with_http_info(
        self,
        test_plan_key: Annotated[StrictStr, Field(description="key of the test plan.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """call_10_api_testplan_test_plan_key_testexecution_post

        Associate test executions with the test plan. Return error messages, if there are any. It's possible to specify if the tests in the test execution should be added to the test plan using the \"addTestsToPlan\" property in the JSON file. If this setting is empty in the JSON file, the config in the Xray miscellaneous will be used.

        :param test_plan_key: key of the test plan. (required)
        :type test_plan_key: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._call_10_api_testplan_test_plan_key_testexecution_post_serialize(
            test_plan_key=test_plan_key,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "Error",
            '401': "Error",
            '500': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def call_10_api_testplan_test_plan_key_testexecution_post_without_preload_content(
        self,
        test_plan_key: Annotated[StrictStr, Field(description="key of the test plan.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """call_10_api_testplan_test_plan_key_testexecution_post

        Associate test executions with the test plan. Return error messages, if there are any. It's possible to specify if the tests in the test execution should be added to the test plan using the \"addTestsToPlan\" property in the JSON file. If this setting is empty in the JSON file, the config in the Xray miscellaneous will be used.

        :param test_plan_key: key of the test plan. (required)
        :type test_plan_key: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._call_10_api_testplan_test_plan_key_testexecution_post_serialize(
            test_plan_key=test_plan_key,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "Error",
            '401': "Error",
            '500': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _call_10_api_testplan_test_plan_key_testexecution_post_serialize(
        self,
        test_plan_key,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if test_plan_key is not None:
            _path_params['testPlanKey'] = test_plan_key
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth', 
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/1.0/api/testplan/{testPlanKey}/testexecution',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def call_10_api_testplan_test_plan_key_testexecution_test_exec_key_delete(
        self,
        test_plan_key: Annotated[StrictStr, Field(description="key of the test plan")],
        test_exec_key: Annotated[StrictStr, Field(description="key of the test")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """call_10_api_testplan_test_plan_key_testexecution_test_exec_key_delete

        Remove test from the test plan.

        :param test_plan_key: key of the test plan (required)
        :type test_plan_key: str
        :param test_exec_key: key of the test (required)
        :type test_exec_key: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._call_10_api_testplan_test_plan_key_testexecution_test_exec_key_delete_serialize(
            test_plan_key=test_plan_key,
            test_exec_key=test_exec_key,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "Error",
            '401': "Error",
            '500': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def call_10_api_testplan_test_plan_key_testexecution_test_exec_key_delete_with_http_info(
        self,
        test_plan_key: Annotated[StrictStr, Field(description="key of the test plan")],
        test_exec_key: Annotated[StrictStr, Field(description="key of the test")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """call_10_api_testplan_test_plan_key_testexecution_test_exec_key_delete

        Remove test from the test plan.

        :param test_plan_key: key of the test plan (required)
        :type test_plan_key: str
        :param test_exec_key: key of the test (required)
        :type test_exec_key: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._call_10_api_testplan_test_plan_key_testexecution_test_exec_key_delete_serialize(
            test_plan_key=test_plan_key,
            test_exec_key=test_exec_key,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "Error",
            '401': "Error",
            '500': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def call_10_api_testplan_test_plan_key_testexecution_test_exec_key_delete_without_preload_content(
        self,
        test_plan_key: Annotated[StrictStr, Field(description="key of the test plan")],
        test_exec_key: Annotated[StrictStr, Field(description="key of the test")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """call_10_api_testplan_test_plan_key_testexecution_test_exec_key_delete

        Remove test from the test plan.

        :param test_plan_key: key of the test plan (required)
        :type test_plan_key: str
        :param test_exec_key: key of the test (required)
        :type test_exec_key: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._call_10_api_testplan_test_plan_key_testexecution_test_exec_key_delete_serialize(
            test_plan_key=test_plan_key,
            test_exec_key=test_exec_key,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "Error",
            '401': "Error",
            '500': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _call_10_api_testplan_test_plan_key_testexecution_test_exec_key_delete_serialize(
        self,
        test_plan_key,
        test_exec_key,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if test_plan_key is not None:
            _path_params['testPlanKey'] = test_plan_key
        if test_exec_key is not None:
            _path_params['testExecKey'] = test_exec_key
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth', 
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/1.0/api/testplan/{testPlanKey}/testexecution/{testExecKey}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Xray REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.models.test_step_result_evidence_input import TestStepResultEvidenceInput

class TestTestStepResultEvidenceInput(unittest.TestCase):
    """TestStepResultEvidenceInput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TestStepResultEvidenceInput:
        """Test TestStepResultEvidenceInput
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TestStepResultEvidenceInput`
        """
        model = TestStepResultEvidenceInput()
        if include_optional:
            return TestStepResultEvidenceInput(
                data = 'iVBORw0KGgoAAAANSUhEUgAABkIAAAO9CAYAAADezXv6AAAAAXNSR0IArs4c6QAA(...base64 file enconding)',
                filename = 'image21.jpg',
                content_type = 'image/jpeg'
            )
        else:
            return TestStepResultEvidenceInput(
        )
        """

    def testTestStepResultEvidenceInput(self):
        """Test TestStepResultEvidenceInput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Xray REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.api.test_plan_tests_api import TestPlanTestsApi


class TestTestPlanTestsApi(unittest.TestCase):
    """TestPlanTestsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TestPlanTestsApi()

    def tearDown(self) -> None:
        pass

    def test_testplan_test_plan_key_test_get(self) -> None:
        """Test case for testplan_test_plan_key_test_get

        """
        pass

    def test_testplan_test_plan_key_test_post(self) -> None:
        """Test case for testplan_test_plan_key_test_post

        """
        pass

    def test_testplan_test_plan_key_test_test_key_delete(self) -> None:
        """Test case for testplan_test_plan_key_test_test_key_delete

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Xray REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.models.update_iteration import UpdateIteration

class TestUpdateIteration(unittest.TestCase):
    """UpdateIteration unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UpdateIteration:
        """Test UpdateIteration
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UpdateIteration`
        """
        model = UpdateIteration()
        if include_optional:
            return UpdateIteration(
                status = 'PASS',
                steps = [
                    openapi_client.models.update_step_result.UpdateStepResult(
                        id = 85778, 
                        status = 'FAIL', 
                        comment = 'Comment on step', 
                        defects = openapi_client.models.update_step_result_defects.UpdateStepResult_defects(
                            add = ["CALC-123","CALC-765"], 
                            remove = ["CALC-563","CALC-744"], ), 
                        evidences = openapi_client.models.update_step_result_evidences.UpdateStepResult_evidences(
                            add = [
                                openapi_client.models.file.File(
                                    data = 'gsddfgdsfg...(base64)', 
                                    filename = 'example.txt', 
                                    content_type = 'plain/text', )
                                ], 
                            remove = ["CALC-124","CALC- 657"], ), 
                        actual_result = 'Actual result on step', )
                    ]
            )
        else:
            return UpdateIteration(
        )
        """

    def testUpdateIteration(self):
        """Test UpdateIteration"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Xray REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.models.get_testruns200_response_inner import GetTestruns200ResponseInner

class TestGetTestruns200ResponseInner(unittest.TestCase):
    """GetTestruns200ResponseInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetTestruns200ResponseInner:
        """Test GetTestruns200ResponseInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetTestruns200ResponseInner`
        """
        model = GetTestruns200ResponseInner()
        if include_optional:
            return GetTestruns200ResponseInner(
                id = 56,
                test_exec_key = '',
                test_key = '',
                status = '',
                type = '',
                test_version = '',
                start = '',
                defects = [
                    ''
                    ],
                evidences = [
                    openapi_client.models.get_testruns_200_response_inner_evidences_inner.get_testruns_200_response_inner_evidences_inner(
                        filename = '', 
                        content_type = '', 
                        data = '', )
                    ],
                steps = [
                    openapi_client.models.get_testruns_200_response_inner_steps_inner.get_testruns_200_response_inner_steps_inner(
                        status = '', 
                        comment = '', 
                        defects = [
                            ''
                            ], 
                        evidences = [
                            openapi_client.models.get_testruns_200_response_inner_evidences_inner.get_testruns_200_response_inner_evidences_inner(
                                filename = '', 
                                content_type = '', 
                                data = '', )
                            ], 
                        actual_result = '', )
                    ],
                parameters = [
                    openapi_client.models.dataset_parameter.DatasetParameter(
                        name = '', 
                        value = '', )
                    ],
                assignee = '',
                test_environments = [
                    ''
                    ],
                comment = ''
            )
        else:
            return GetTestruns200ResponseInner(
        )
        """

    def testGetTestruns200ResponseInner(self):
        """Test GetTestruns200ResponseInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Xray REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictStr, field_validator
from typing import Optional, Tuple, Union
from typing_extensions import Annotated

from openapi_client.api_client import ApiClient, RequestSerialized
from openapi_client.api_response import ApiResponse
from openapi_client.rest import RESTResponseType


class DatasetApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def call_10_api_dataset_export_get(
        self,
        test_issue_id: Annotated[Optional[StrictStr], Field(description="The id of the test issue")] = None,
        test_issue_key: Annotated[Optional[StrictStr], Field(description="The key of the test issue")] = None,
        test_version: Annotated[Optional[StrictStr], Field(description="A test version")] = None,
        context_issue_id: Annotated[Optional[StrictStr], Field(description="The id of the context issue (Test Plan or Test Execution)")] = None,
        context_issue_key: Annotated[Optional[StrictStr], Field(description="The key of the context issue (Test Plan or Test Execution)")] = None,
        resolved: Annotated[Optional[StrictStr], Field(description="A flag indicating of the dataset must be resolved or not for a given level (true by default)")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> str:
        """call_10_api_dataset_export_get

        Retrieves a CSV file with the dataset information. <br/> The response will contain all information related to the dataset, e.g., parameters and values. <br/>

        :param test_issue_id: The id of the test issue
        :type test_issue_id: str
        :param test_issue_key: The key of the test issue
        :type test_issue_key: str
        :param test_version: A test version
        :type test_version: str
        :param context_issue_id: The id of the context issue (Test Plan or Test Execution)
        :type context_issue_id: str
        :param context_issue_key: The key of the context issue (Test Plan or Test Execution)
        :type context_issue_key: str
        :param resolved: A flag indicating of the dataset must be resolved or not for a given level (true by default)
        :type resolved: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._call_10_api_dataset_export_get_serialize(
            test_issue_id=test_issue_id,
            test_issue_key=test_issue_key,
            test_version=test_version,
            context_issue_id=context_issue_id,
            context_issue_key=context_issue_key,
            resolved=resolved,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "str",
            '400': "Error",
            '403': "Error",
            '404': "Error",
            '500': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def call_10_api_dataset_export_get_with_http_info(
        self,
        test_issue_id: Annotated[Optional[StrictStr], Field(description="The id of the test issue")] = None,
        test_issue_key: Annotated[Optional[StrictStr], Field(description="The key of the test issue")] = None,
        test_version: Annotated[Optional[StrictStr], Field(description="A test version")] = None,
        context_issue_id: Annotated[Optional[StrictStr], Field(description="The id of the context issue (Test Plan or Test Execution)")] = None,
        context_issue_key: Annotated[Optional[StrictStr], Field(description="The key of the context issue (Test Plan or Test Execution)")] = None,
        resolved: Annotated[Optional[StrictStr], Field(description="A flag indicating of the dataset must be resolved or not for a given level (true by default)")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[str]:
        """call_10_api_dataset_export_get

        Retrieves a CSV file with the dataset information. <br/> The response will contain all information related to the dataset, e.g., parameters and values. <br/>

        :param test_issue_id: The id of the test issue
        :type test_issue_id: str
        :param test_issue_key: The key of the test issue
        :type test_issue_key: str
        :param test_version: A test version
        :type test_version: str
        :param context_issue_id: The id of the context issue (Test Plan or Test Execution)
        :type context_issue_id: str
        :param context_issue_key: The key of the context issue (Test Plan or Test Execution)
        :type context_issue_key: str
        :param resolved: A flag indicating of the dataset must be resolved or not for a given level (true by default)
        :type resolved: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._call_10_api_dataset_export_get_serialize(
            test_issue_id=test_issue_id,
            test_issue_key=test_issue_key,
            test_version=test_version,
            context_issue_id=context_issue_id,
            context_issue_key=context_issue_key,
            resolved=resolved,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "str",
            '400': "Error",
            '403': "Error",
            '404': "Error",
            '500': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def call_10_api_dataset_export_get_without_preload_content(
        self,
        test_issue_id: Annotated[Optional[StrictStr], Field(description="The id of the test issue")] = None,
        test_issue_key: Annotated[Optional[StrictStr], Field(description="The key of the test issue")] = None,
        test_version: Annotated[Optional[StrictStr], Field(description="A test version")] = None,
        context_issue_id: Annotated[Optional[StrictStr], Field(description="The id of the context issue (Test Plan or Test Execution)")] = None,
        context_issue_key: Annotated[Optional[StrictStr], Field(description="The key of the context issue (Test Plan or Test Execution)")] = None,
        resolved: Annotated[Optional[StrictStr], Field(description="A flag indicating of the dataset must be resolved or not for a given level (true by default)")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """call_10_api_dataset_export_get

        Retrieves a CSV file with the dataset information. <br/> The response will contain all information related to the dataset, e.g., parameters and values. <br/>

        :param test_issue_id: The id of the test issue
        :type test_issue_id: str
        :param test_issue_key: The key of the test issue
        :type test_issue_key: str
        :param test_version: A test version
        :type test_version: str
        :param context_issue_id: The id of the context issue (Test Plan or Test Execution)
        :type context_issue_id: str
        :param context_issue_key: The key of the context issue (Test Plan or Test Execution)
        :type context_issue_key: str
        :param resolved: A flag indicating of the dataset must be resolved or not for a given level (true by default)
        :type resolved: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._call_10_api_dataset_export_get_serialize(
            test_issue_id=test_issue_id,
            test_issue_key=test_issue_key,
            test_version=test_version,
            context_issue_id=context_issue_id,
            context_issue_key=context_issue_key,
            resolved=resolved,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "str",
            '400': "Error",
            '403': "Error",
            '404': "Error",
            '500': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _call_10_api_dataset_export_get_serialize(
        self,
        test_issue_id,
        test_issue_key,
        test_version,
        context_issue_id,
        context_issue_key,
        resolved,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if test_issue_id is not None:
            
            _query_params.append(('testIssueId', test_issue_id))
            
        if test_issue_key is not None:
            
            _query_params.append(('testIssueKey', test_issue_key))
            
        if test_version is not None:
            
            _query_params.append(('testVersion', test_version))
            
        if context_issue_id is not None:
            
            _query_params.append(('contextIssueId', context_issue_id))
            
        if context_issue_key is not None:
            
            _query_params.append(('contextIssueKey', context_issue_key))
            
        if resolved is not None:
            
            _query_params.append(('resolved', resolved))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'text/csv', 
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth', 
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/1.0/api/dataset/export',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def call_10_api_dataset_import_post(
        self,
        file: Annotated[Union[Annotated[bytes, Field(strict=True)], Annotated[str, Field(strict=True)], Tuple[str, Annotated[bytes, Field(strict=True)]]], Field(description="The file must be of type CSV. On the first line are presented the parameter names and the lines below represent their values. In order for a parameter to be considered combinatorial, it must contain '*' as a suffix. The CSV delimiter is ','.   ```  Browser*,Languague  Firefox,Portuguese  Chrome,English  ``` ")],
        test_issue_id: Annotated[Optional[StrictStr], Field(description="The id of the test issue")] = None,
        test_issue_key: Annotated[Optional[StrictStr], Field(description="The key of the test issue")] = None,
        test_version: Annotated[Optional[StrictStr], Field(description="The test version")] = None,
        context_issue_id: Annotated[Optional[StrictStr], Field(description="The id of the context issue (Test Plan or Test Execution)")] = None,
        context_issue_key: Annotated[Optional[StrictStr], Field(description="The key of the context issue (Test Plan or Test Execution)")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """call_10_api_dataset_import_post

        Endpoint used to imports a dataset through a CSV file to an entity. <br> It is only possible to import dataset to the following entities: <br>   <ul>     <li> Test </li>     <li> Test Plan - Test </li>     <li> Test Execution - Test (Test Run) </li>

        :param file: The file must be of type CSV. On the first line are presented the parameter names and the lines below represent their values. In order for a parameter to be considered combinatorial, it must contain '*' as a suffix. The CSV delimiter is ','.   ```  Browser*,Languague  Firefox,Portuguese  Chrome,English  ```  (required)
        :type file: bytearray
        :param test_issue_id: The id of the test issue
        :type test_issue_id: str
        :param test_issue_key: The key of the test issue
        :type test_issue_key: str
        :param test_version: The test version
        :type test_version: str
        :param context_issue_id: The id of the context issue (Test Plan or Test Execution)
        :type context_issue_id: str
        :param context_issue_key: The key of the context issue (Test Plan or Test Execution)
        :type context_issue_key: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._call_10_api_dataset_import_post_serialize(
            file=file,
            test_issue_id=test_issue_id,
            test_issue_key=test_issue_key,
            test_version=test_version,
            context_issue_id=context_issue_id,
            context_issue_key=context_issue_key,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "Error",
            '403': "Error",
            '500': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def call_10_api_dataset_import_post_with_http_info(
        self,
        file: Annotated[Union[Annotated[bytes, Field(strict=True)], Annotated[str, Field(strict=True)], Tuple[str, Annotated[bytes, Field(strict=True)]]], Field(description="The file must be of type CSV. On the first line are presented the parameter names and the lines below represent their values. In order for a parameter to be considered combinatorial, it must contain '*' as a suffix. The CSV delimiter is ','.   ```  Browser*,Languague  Firefox,Portuguese  Chrome,English  ``` ")],
        test_issue_id: Annotated[Optional[StrictStr], Field(description="The id of the test issue")] = None,
        test_issue_key: Annotated[Optional[StrictStr], Field(description="The key of the test issue")] = None,
        test_version: Annotated[Optional[StrictStr], Field(description="The test version")] = None,
        context_issue_id: Annotated[Optional[StrictStr], Field(description="The id of the context issue (Test Plan or Test Execution)")] = None,
        context_issue_key: Annotated[Optional[StrictStr], Field(description="The key of the context issue (Test Plan or Test Execution)")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """call_10_api_dataset_import_post

        Endpoint used to imports a dataset through a CSV file to an entity. <br> It is only possible to import dataset to the following entities: <br>   <ul>     <li> Test </li>     <li> Test Plan - Test </li>     <li> Test Execution - Test (Test Run) </li>

        :param file: The file must be of type CSV. On the first line are presented the parameter names and the lines below represent their values. In order for a parameter to be considered combinatorial, it must contain '*' as a suffix. The CSV delimiter is ','.   ```  Browser*,Languague  Firefox,Portuguese  Chrome,English  ```  (required)
        :type file: bytearray
        :param test_issue_id: The id of the test issue
        :type test_issue_id: str
        :param test_issue_key: The key of the test issue
        :type test_issue_key: str
        :param test_version: The test version
        :type test_version: str
        :param context_issue_id: The id of the context issue (Test Plan or Test Execution)
        :type context_issue_id: str
        :param context_issue_key: The key of the context issue (Test Plan or Test Execution)
        :type context_issue_key: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._call_10_api_dataset_import_post_serialize(
            file=file,
            test_issue_id=test_issue_id,
            test_issue_key=test_issue_key,
            test_version=test_version,
            context_issue_id=context_issue_id,
            context_issue_key=context_issue_key,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "Error",
            '403': "Error",
            '500': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def call_10_api_dataset_import_post_without_preload_content(
        self,
        file: Annotated[Union[Annotated[bytes, Field(strict=True)], Annotated[str, Field(strict=True)], Tuple[str, Annotated[bytes, Field(strict=True)]]], Field(description="The file must be of type CSV. On the first line are presented the parameter names and the lines below represent their values. In order for a parameter to be considered combinatorial, it must contain '*' as a suffix. The CSV delimiter is ','.   ```  Browser*,Languague  Firefox,Portuguese  Chrome,English  ``` ")],
        test_issue_id: Annotated[Optional[StrictStr], Field(description="The id of the test issue")] = None,
        test_issue_key: Annotated[Optional[StrictStr], Field(description="The key of the test issue")] = None,
        test_version: Annotated[Optional[StrictStr], Field(description="The test version")] = None,
        context_issue_id: Annotated[Optional[StrictStr], Field(description="The id of the context issue (Test Plan or Test Execution)")] = None,
        context_issue_key: Annotated[Optional[StrictStr], Field(description="The key of the context issue (Test Plan or Test Execution)")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """call_10_api_dataset_import_post

        Endpoint used to imports a dataset through a CSV file to an entity. <br> It is only possible to import dataset to the following entities: <br>   <ul>     <li> Test </li>     <li> Test Plan - Test </li>     <li> Test Execution - Test (Test Run) </li>

        :param file: The file must be of type CSV. On the first line are presented the parameter names and the lines below represent their values. In order for a parameter to be considered combinatorial, it must contain '*' as a suffix. The CSV delimiter is ','.   ```  Browser*,Languague  Firefox,Portuguese  Chrome,English  ```  (required)
        :type file: bytearray
        :param test_issue_id: The id of the test issue
        :type test_issue_id: str
        :param test_issue_key: The key of the test issue
        :type test_issue_key: str
        :param test_version: The test version
        :type test_version: str
        :param context_issue_id: The id of the context issue (Test Plan or Test Execution)
        :type context_issue_id: str
        :param context_issue_key: The key of the context issue (Test Plan or Test Execution)
        :type context_issue_key: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._call_10_api_dataset_import_post_serialize(
            file=file,
            test_issue_id=test_issue_id,
            test_issue_key=test_issue_key,
            test_version=test_version,
            context_issue_id=context_issue_id,
            context_issue_key=context_issue_key,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "Error",
            '403': "Error",
            '500': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _call_10_api_dataset_import_post_serialize(
        self,
        file,
        test_issue_id,
        test_issue_key,
        test_version,
        context_issue_id,
        context_issue_key,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if test_issue_id is not None:
            
            _query_params.append(('testIssueId', test_issue_id))
            
        if test_issue_key is not None:
            
            _query_params.append(('testIssueKey', test_issue_key))
            
        if test_version is not None:
            
            _query_params.append(('testVersion', test_version))
            
        if context_issue_id is not None:
            
            _query_params.append(('contextIssueId', context_issue_id))
            
        if context_issue_key is not None:
            
            _query_params.append(('contextIssueKey', context_issue_key))
            
        # process the header parameters
        # process the form parameters
        if file is not None:
            _files['file'] = file
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'multipart/form-data'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth', 
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/1.0/api/dataset/import',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Xray REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.models.model10_api_testrepository_project_key_folders_folder_id_get200_response import Model10ApiTestrepositoryProjectKeyFoldersFolderIdGet200Response

class TestModel10ApiTestrepositoryProjectKeyFoldersFolderIdGet200Response(unittest.TestCase):
    """Model10ApiTestrepositoryProjectKeyFoldersFolderIdGet200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Model10ApiTestrepositoryProjectKeyFoldersFolderIdGet200Response:
        """Test Model10ApiTestrepositoryProjectKeyFoldersFolderIdGet200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Model10ApiTestrepositoryProjectKeyFoldersFolderIdGet200Response`
        """
        model = Model10ApiTestrepositoryProjectKeyFoldersFolderIdGet200Response()
        if include_optional:
            return Model10ApiTestrepositoryProjectKeyFoldersFolderIdGet200Response(
                id = 1001,
                rank = 1,
                name = 'Unit Tests',
                test_count = 2,
                total_test_count = 12,
                test_repository_path = '/v4.3.2/AutomatedTests',
                folder_ids = [1002, 1003]
            )
        else:
            return Model10ApiTestrepositoryProjectKeyFoldersFolderIdGet200Response(
        )
        """

    def testModel10ApiTestrepositoryProjectKeyFoldersFolderIdGet200Response(self):
        """Test Model10ApiTestrepositoryProjectKeyFoldersFolderIdGet200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Xray REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from openapi_client.models.dataset_parameter import DatasetParameter
from openapi_client.models.file_response import FileResponse
from openapi_client.models.step_result import StepResult
from openapi_client.models.test_run_iteration_status_information import TestRunIterationStatusInformation
from openapi_client.models.test_run_response_custom_fields_inner import TestRunResponseCustomFieldsInner
from openapi_client.models.version import Version
from typing import Optional, Set
from typing_extensions import Self

class TestRunResponse(BaseModel):
    """
    TestRunResponse
    """ # noqa: E501
    id: Optional[StrictInt] = None
    status: Optional[StrictStr] = None
    color: Optional[StrictStr] = None
    test_key: Optional[StrictStr] = Field(default=None, alias="testKey")
    test_exec_key: Optional[StrictStr] = Field(default=None, alias="testExecKey")
    test_version: Optional[StrictStr] = Field(default=None, alias="testVersion")
    assignee: Optional[StrictStr] = None
    executed_by: Optional[StrictStr] = Field(default=None, alias="executedBy")
    started_on: Optional[StrictStr] = Field(default=None, alias="startedOn")
    finished_on: Optional[StrictStr] = Field(default=None, alias="finishedOn")
    started_on_iso: Optional[StrictStr] = Field(default=None, alias="startedOnIso")
    finished_on_iso: Optional[StrictStr] = Field(default=None, alias="finishedOnIso")
    duration: Optional[StrictInt] = None
    defects: Optional[List[StrictStr]] = None
    evidences: Optional[List[FileResponse]] = None
    comment: Optional[StrictStr] = None
    test_environments: Optional[List[StrictStr]] = Field(default=None, alias="testEnvironments")
    fix_versions: Optional[List[Version]] = Field(default=None, alias="fixVersions")
    custom_fields: Optional[List[TestRunResponseCustomFieldsInner]] = Field(default=None, alias="customFields")
    steps: Optional[List[StepResult]] = None
    iterations: Optional[List[TestRunIterationStatusInformation]] = None
    parameters: Optional[List[DatasetParameter]] = None
    __properties: ClassVar[List[str]] = ["id", "status", "color", "testKey", "testExecKey", "testVersion", "assignee", "executedBy", "startedOn", "finishedOn", "startedOnIso", "finishedOnIso", "duration", "defects", "evidences", "comment", "testEnvironments", "fixVersions", "customFields", "steps", "iterations", "parameters"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TestRunResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in evidences (list)
        _items = []
        if self.evidences:
            for _item_evidences in self.evidences:
                if _item_evidences:
                    _items.append(_item_evidences.to_dict())
            _dict['evidences'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in fix_versions (list)
        _items = []
        if self.fix_versions:
            for _item_fix_versions in self.fix_versions:
                if _item_fix_versions:
                    _items.append(_item_fix_versions.to_dict())
            _dict['fixVersions'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in custom_fields (list)
        _items = []
        if self.custom_fields:
            for _item_custom_fields in self.custom_fields:
                if _item_custom_fields:
                    _items.append(_item_custom_fields.to_dict())
            _dict['customFields'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in steps (list)
        _items = []
        if self.steps:
            for _item_steps in self.steps:
                if _item_steps:
                    _items.append(_item_steps.to_dict())
            _dict['steps'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in iterations (list)
        _items = []
        if self.iterations:
            for _item_iterations in self.iterations:
                if _item_iterations:
                    _items.append(_item_iterations.to_dict())
            _dict['iterations'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in parameters (list)
        _items = []
        if self.parameters:
            for _item_parameters in self.parameters:
                if _item_parameters:
                    _items.append(_item_parameters.to_dict())
            _dict['parameters'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TestRunResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "status": obj.get("status"),
            "color": obj.get("color"),
            "testKey": obj.get("testKey"),
            "testExecKey": obj.get("testExecKey"),
            "testVersion": obj.get("testVersion"),
            "assignee": obj.get("assignee"),
            "executedBy": obj.get("executedBy"),
            "startedOn": obj.get("startedOn"),
            "finishedOn": obj.get("finishedOn"),
            "startedOnIso": obj.get("startedOnIso"),
            "finishedOnIso": obj.get("finishedOnIso"),
            "duration": obj.get("duration"),
            "defects": obj.get("defects"),
            "evidences": [FileResponse.from_dict(_item) for _item in obj["evidences"]] if obj.get("evidences") is not None else None,
            "comment": obj.get("comment"),
            "testEnvironments": obj.get("testEnvironments"),
            "fixVersions": [Version.from_dict(_item) for _item in obj["fixVersions"]] if obj.get("fixVersions") is not None else None,
            "customFields": [TestRunResponseCustomFieldsInner.from_dict(_item) for _item in obj["customFields"]] if obj.get("customFields") is not None else None,
            "steps": [StepResult.from_dict(_item) for _item in obj["steps"]] if obj.get("steps") is not None else None,
            "iterations": [TestRunIterationStatusInformation.from_dict(_item) for _item in obj["iterations"]] if obj.get("iterations") is not None else None,
            "parameters": [DatasetParameter.from_dict(_item) for _item in obj["parameters"]] if obj.get("parameters") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Xray REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.models.create_step import CreateStep

class TestCreateStep(unittest.TestCase):
    """CreateStep unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateStep:
        """Test CreateStep
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateStep`
        """
        model = CreateStep()
        if include_optional:
            return CreateStep(
                fields = {"Action":"Step Action","Date":"02/Feb/2020","Toggle":"true","SingleSelectList":"Selected Value","MultiSelectList":["Option A","Option B"]},
                attachments = [
                    openapi_client.models.file.File(
                        data = 'gsddfgdsfg...(base64)', 
                        filename = 'example.txt', 
                        content_type = 'plain/text', )
                    ]
            )
        else:
            return CreateStep(
        )
        """

    def testCreateStep(self):
        """Test CreateStep"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
